Index: ruby/branches/0.0/models/rm/data_types/text.rb
===================================================================
--- ruby/branches/0.0/models/rm/data_types/text.rb	(revision 31)
+++ ruby/branches/0.0/models/rm/data_types/text.rb	(revision 167)
@@ -1,7 +1,7 @@
-module OpenEHR
+module OpenEhr
   module RM
-    module Data_Types
+    module DataTypes
       module Text
-        class Term_Mapping
+        class TermMapping
           attr_reader :match, :purpose, :target
           def initialize(match, purpose, target)
@@ -23,5 +23,5 @@
             match == '?'
           end
-          def Term_Mapping.is_valid_mach_code?(c)
+          def TermMapping.is_valid_mach_code?(c)
             c == '>' or c == '=' or c == '<' or c == '?'
           end
@@ -31,5 +31,5 @@
           end
           def purpose_valid(purpose)
-            if !purpose.nil? and !purpose.instance_of? DV_Coded_Text
+            if !purpose.nil? and !purpose.instance_of? DvCodedText
               raise ArgumentError, "purpose is not valid"
             end
@@ -41,5 +41,5 @@
         end
 
-        class Code_Phrase
+        class CodePhrase
           attr_reader :terminology_id, :code_string
           def initialize(terminology_id, code_string)
@@ -50,14 +50,14 @@
               raise Exception.new("empty codeString")
             end
-            if terminology_id.instance_of?(Terminology_ID)
+            if terminology_id.instance_of?(TerminologyId)
               @terminology_id = terminology_id
             else
-              @terminologyID = Terminology_ID.new(terminology_id)
+              @terminologyID = TerminologyId.new(terminology_id)
             end
             @code_string = code_string
           end
-        end # of Code_Phrase
+        end # of CodePhrase
 
-        class DV_Text < OpenEHR::RM::Data_Types::Basic::Data_Value
+        class DvText < OpenEhr::RM::DataTypes::Basic::DataValue
           attr_reader :value, :formatting, :hyperlink, :mappings
           attr_reader :language, :encoding
@@ -65,8 +65,8 @@
                          mappings = nil, language = nil, encoding = nil)
             value_valid(value)
-            DV_Text.formatting_valid(formatting)
-            DV_Text.encoding_valid(encoding)
-            DV_Text.mapping_valid(mappings)
-            DV_Text.language_valid(language)
+            DvText.formatting_valid(formatting)
+            DvText.encoding_valid(encoding)
+            DvText.mapping_valid(mappings)
+            DvText.language_valid(language)
             @value, @formatting, @encoding = value, formatting, encoding
             @mappings, @language = mappings, language
@@ -77,17 +77,17 @@
           end
           def formatting=(formatting)
-            DV_Text.formatting_valid(formatting)
+            DvText.formatting_valid(formatting)
             @formatting = formatting
           end
           def encoding=(encoding)
-            DV_Text.encoding_valid(encoding)
+            DvText.encoding_valid(encoding)
             @encoding = encoding
           end
           def mappings=(mappings)
-            DV_Text.mapping_valid(mappings)
+            DvText.mapping_valid(mappings)
             @mappings = mappings
           end
           def language=(language)
-            DV_Text.language_valid(language)
+            DvText.language_valid(language)
             @language = language
           end
@@ -96,5 +96,5 @@
             if value.nil? or value.empty? or value.include? CR or value.include? LF
               raise ArgumentError, "value is not valid"
               # CR and LF are defined in Basic_Definition inherited Data_Value.
             end
           end
@@ -125,5 +125,5 @@
         end
 
-        class DV_Coded_Text < DV_Text
+        class DvCodedText < DvText
           attr_reader :defining_code
           def initialize(value, defining_code, formatting = nil, 
@@ -144,5 +144,5 @@
         end
 
-        class DV_Paragraph < OpenEHR::RM::Data_Types::Basic::Data_Value
+        class DvParagraph < OpenEhr::RM::DataTypes::Basic::DataValue
           attr_reader :items
           def initialize(items)
@@ -96,5 +96,5 @@
             if value.nil? or value.empty? or value.include? CR or value.include? LF
               raise ArgumentError, "value is not valid"
-              # CR and LF are defined in Basic_Definition inherited Data_Value.
+              # CR and LF are defined in Basic_Definition inherited DataValue.
             end
           end
